@@ -164,11 +164,11 @@ void MuonDiscoverMainWindow::openCategory(const QString& category)
 
 void MuonDiscoverMainWindow::openApplication(const QString& app)
 {
-    rootObject()->setProperty("defaultStartup", false);
     m_appToBeOpened = app;
-    triggerOpenApplication();
     if(!m_appToBeOpened.isEmpty()) {
-        if (ResourcesModel::global()->isFetching()) {
+        rootObject()->setProperty("defaultStartup", false);
+
+        if (ResourcesModel::global()->isFetching() || ResourcesModel::global()->backends().isEmpty()) {
             connect(ResourcesModel::global(), &ResourcesModel::rowsInserted, this, &MuonDiscoverMainWindow::triggerOpenApplication);
         } else {
             triggerOpenApplication();
@@ -195,7 +195,7 @@ QUrl MuonDiscoverMainWindow::featuredSource() const
 
 QUrl MuonDiscoverMainWindow::prioritaryFeaturedSource() const
 {
-    return QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("featured.json")));
+    return QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("plasmadiscover/featured.json")));
 }
 
 bool MuonDiscoverMainWindow::isCompact() const
@@ -203,7 +203,7 @@ bool MuonDiscoverMainWindow::isCompact() const
     if (m_mode != Auto) {
         return m_mode == Compact;
     } else if (!isVisible())
-        return true;
+        return false;
 
     const qreal pixelDensity = screen()->physicalDotsPerInch() / 25.4;
     return (width()/pixelDensity)<100; //we'll use compact if the width of the window is less than 10cm
@@ -230,8 +230,13 @@ void MuonDiscoverMainWindow::showEvent(QShowEvent * event)
 
 void MuonDiscoverMainWindow::hideEvent(QHideEvent * event)
 {
-    delete engine();
-    QQuickView::hideEvent(event);
+    if (!ResourcesModel::global()->isBusy()) {
+        delete engine();
+        QQuickView::hideEvent(event);
+    } else {
+        qWarning() << "not closing because there's still pending tasks";
+        Q_EMIT preventedClose();
+    }
 }
 
 void MuonDiscoverMainWindow::setupActions()
