@@ -22,11 +22,9 @@
 
 // Qt includes
 #include <QFont>
-#include <QApplication>
 #include <QDebug>
 
 // KDE includes
-#include <KIconLoader>
 #include <KFormat>
 #include <KLocalizedString>
 
@@ -38,24 +36,22 @@
 
 UpdateModel::UpdateModel(QObject *parent)
     : QAbstractItemModel(parent)
+    , m_rootItem(new UpdateItem)
     , m_updates(nullptr)
     , m_updatesCount(0)
 {
-    m_rootItem = new UpdateItem();
 
     connect(ResourcesModel::global(), &ResourcesModel::fetchingChanged, this, &UpdateModel::activityChanged);
     connect(ResourcesModel::global(), &ResourcesModel::updatesCountChanged, this, &UpdateModel::activityChanged);
 }
 
-UpdateModel::~UpdateModel()
-{
-    delete m_rootItem;
-}
+UpdateModel::~UpdateModel() = default;
 
 QHash<int,QByteArray> UpdateModel::roleNames() const
 {
     return QAbstractItemModel::roleNames().unite({
         { Qt::CheckStateRole, "checked" },
+        { ResourceProgressRole, "resourceProgress" },
         { ResourceRole, "resource" },
         { SizeRole, "size" },
         { VersionRole, "version" }
@@ -71,10 +67,21 @@ void UpdateModel::setBackend(ResourcesUpdatesModel* updates)
     m_updates = updates;
 
     connect(m_updates, &ResourcesUpdatesModel::progressingChanged, this, &UpdateModel::activityChanged);
+    connect(m_updates, &ResourcesUpdatesModel::resourceProgressed, this, &UpdateModel::resourceHasProgressed);
 
     activityChanged();
 }
 
+void UpdateModel::resourceHasProgressed(AbstractResource* res, qreal progress)
+{
+    UpdateItem* item = itemFromResource(res, m_rootItem.data());
+    Q_ASSERT(item);
+    item->setProgress(progress);
+
+    QModelIndex idx = indexFromItem(item);
+    Q_EMIT dataChanged(idx, idx);
+}
+
 void UpdateModel::activityChanged()
 {
     if(ResourcesModel::global()->isFetching()) {
@@ -129,6 +136,8 @@ QVariant UpdateModel::data(const QModelIndex &index, int role) const
         return KFormat().formatByteSize(item->size());
     case ResourceRole:
         return QVariant::fromValue<QObject*>(item->resource());
+    case ResourceProgressRole:
+        return item->progress();
     default:
         break;
     }
@@ -138,14 +147,10 @@ QVariant UpdateModel::data(const QModelIndex &index, int role) const
 
 void UpdateModel::checkResources(const QList<AbstractResource*>& resource, bool checked)
 {
-    if (resource.size() > 1) {
-        QApplication::setOverrideCursor(Qt::WaitCursor);
-    }
     if(checked)
         m_updates->addResources(resource);
     else
         m_updates->removeResources(resource);
-    QApplication::restoreOverrideCursor();
 }
 
 QVariant UpdateModel::headerData(int section, Qt::Orientation orientation,
@@ -199,7 +204,7 @@ QModelIndex UpdateModel::parent(const QModelIndex &index) const
     UpdateItem *childItem = itemFromIndex(index);
     UpdateItem *parentItem = childItem->parent();
 
-    if (parentItem == m_rootItem) {
+    if (parentItem == m_rootItem.data()) {
         return QModelIndex();
     }
 
@@ -226,14 +231,14 @@ UpdateItem* UpdateModel::itemFromIndex(const QModelIndex &index) const
 {
     if (index.isValid())
          return static_cast<UpdateItem*>(index.internalPointer());
-    return m_rootItem;
+    return m_rootItem.data();
 }
 
 bool UpdateModel::setData(const QModelIndex &idx, const QVariant &value, int role)
 {
     if (role == Qt::CheckStateRole) {
         UpdateItem *item = static_cast<UpdateItem*>(idx.internalPointer());
-        bool newValue = value.toBool();
+        const bool newValue = value.toInt() == Qt::Checked;
         UpdateItem::ItemType type = item->type();
 
         QList<AbstractResource *> apps;
@@ -266,50 +271,43 @@ bool UpdateModel::setData(const QModelIndex &idx, const QVariant &value, int rol
 void UpdateModel::setResources(const QList< AbstractResource* >& resources)
 {
     beginResetModel();
-    delete m_rootItem;
-    m_rootItem = new UpdateItem;
-
-    UpdateItem *securityItem = new UpdateItem(i18nc("@item:inlistbox", "Important Security Updates"),
-                                              QIcon::fromTheme(QStringLiteral("security-medium")));
-
-    UpdateItem *appItem = new UpdateItem(i18nc("@item:inlistbox", "Application Updates"),
-                                          QIcon::fromTheme(QStringLiteral("applications-other")));
-
-    UpdateItem *systemItem = new UpdateItem(i18nc("@item:inlistbox", "System Updates"),
-                                             QIcon::fromTheme(QStringLiteral("applications-system")));
+    m_rootItem.reset(new UpdateItem);
 
+    QVector<UpdateItem*> securityItems, appItems, systemItems;
     foreach(AbstractResource* res, resources) {
         UpdateItem *updateItem = new UpdateItem(res);
+
         if (res->isFromSecureOrigin()) {
-            securityItem->appendChild(updateItem);
+            securityItems += updateItem;
         } else if(!res->isTechnical()) {
-            appItem->appendChild(updateItem);
+            appItems += updateItem;
         } else {
-            systemItem->appendChild(updateItem);
+            systemItems += updateItem;
         }
     }
 
-    // Add populated items to the model
-    if (securityItem->childCount()) {
-        securityItem->sort();
-        m_rootItem->appendChild(securityItem);
-    } else {
-        delete securityItem;
+    QVector<UpdateItem*> categoryItems;
+    if (!securityItems.isEmpty()) {
+        UpdateItem *securityItem = new UpdateItem(i18nc("@item:inlistbox", "Important Security Updates"),
+                                            QIcon::fromTheme(QStringLiteral("security-medium")));
+        securityItem->setChildren(securityItems);
+        categoryItems += securityItem;
     }
 
-    if (appItem->childCount()) {
-        appItem->sort();
-        m_rootItem->appendChild(appItem);
-    } else {
-        delete appItem;
+    if (!appItems.isEmpty()) {
+        UpdateItem *appItem = new UpdateItem(i18nc("@item:inlistbox", "Application Updates"),
+                                          QIcon::fromTheme(QStringLiteral("applications-other")));
+        appItem->setChildren(appItems);
+        categoryItems += appItem;
     }
 
-    if (systemItem->childCount()) {
-        systemItem->sort();
-        m_rootItem->appendChild(systemItem);
-    } else {
-        delete systemItem;
+    if (!systemItems.isEmpty()) {
+        UpdateItem *systemItem = new UpdateItem(i18nc("@item:inlistbox", "System Updates"),
+                                             QIcon::fromTheme(QStringLiteral("applications-system")));
+        systemItem->setChildren(systemItems);
+        categoryItems += systemItem;
     }
+    m_rootItem->setChildren(categoryItems);
     endResetModel();
 
     m_updatesCount = resources.count();
@@ -336,3 +334,30 @@ int UpdateModel::toUpdateCount() const
 {
     return m_rootItem->checkedItems();
 }
+
+UpdateItem * UpdateModel::itemFromResource(AbstractResource* res, UpdateItem* root)
+{
+    if (root->app()) {
+        if (root->app() == res)
+            return root;
+    } else {
+        foreach (UpdateItem* cat, root->children()) {
+            UpdateItem* item = itemFromResource(res, cat);
+            if (item)
+                return item;
+        }
+    }
+    return nullptr;
+}
+
+QModelIndex UpdateModel::indexFromItem(UpdateItem* item) const
+{
+    if (item == m_rootItem.data()) {
+        return QModelIndex();
+    }
+    UpdateItem* parentItem = item->parent();
+    QModelIndex parent = indexFromItem(parentItem);
+
+    int row = parentItem->children().indexOf(item);
+    return index(row, 0, parent);
+}
