@@ -41,6 +41,8 @@
 #include <KIconLoader>
 #include <KXmlGuiWindow>
 
+#include <AppstreamQt/database.h>
+
 // QApt/DebconfKDE includes
 #include <QApt/Backend>
 #include <QApt/Transaction>
@@ -61,8 +63,6 @@
 #include <resources/SourcesModel.h>
 #include <MuonDataSources.h>
 
-// static const KCatalogLoader loader("app-install-data"); //FIXME port
-
 MUON_BACKEND_PLUGIN(ApplicationBackend)
 
 ApplicationBackend::ApplicationBackend(QObject* parent)
@@ -91,13 +91,16 @@ ApplicationBackend::~ApplicationBackend()
 
 QVector<Application *> init(QApt::Backend *backend, QThread* thread)
 {
-    QDir appDir(QStringLiteral("/usr/share/app-install/desktop/"));
-    QStringList fileList = appDir.entryList(QStringList(QStringLiteral("*.desktop")), QDir::Files);
+    Appstream::Database appdata;
+    bool opened = appdata.open();
+    Q_ASSERT(opened);
 
     QVector<Application *> tempList;
     QSet<QString> packages;
-    foreach(const QString &fileName, fileList) {
-        Application *app = new Application(appDir.filePath(fileName), backend);
+    foreach(const Appstream::Component &component, appdata.allComponents()) {
+        if (component.packageNames().isEmpty())
+            continue;
+        Application *app = new Application(component, backend);
         packages.insert(app->packageName());
         tempList << app;
     }
@@ -459,7 +462,7 @@ QVector<AbstractResource*> ApplicationBackend::allResources() const
     return ret;
 }
 
-void ApplicationBackend::installApplication(AbstractResource* res, AddonList addons)
+void ApplicationBackend::installApplication(AbstractResource* res, const AddonList& addons)
 {
     Application* app = qobject_cast<Application*>(res);
     Transaction::Role role = app->package()->isInstalled() ? Transaction::ChangeAddonsRole : Transaction::InstallRole;
@@ -494,7 +497,7 @@ AbstractResource* ApplicationBackend::resourceByPackageName(const QString& name)
         if(app->packageName()==name)
             return app;
     }
-    return 0;
+    return nullptr;
 }
 
 QList<AbstractResource*> ApplicationBackend::searchPackageName(const QString& searchText)
@@ -520,16 +523,16 @@ AbstractBackendUpdater* ApplicationBackend::backendUpdater() const
     return m_backendUpdater;
 }
 
-void ApplicationBackend::integrateMainWindow(KXmlGuiWindow* w)
+void ApplicationBackend::integrateActions(KActionCollection* w)
 {
     m_aptify = w;
     QAptActions* apt = QAptActions::self();
-    apt->setMainWindow(w);
+    apt->setActionCollection(w);
     if(!m_aptBackendInitialized)
         connect(this, &ApplicationBackend::aptBackendInitialized, apt, &QAptActions::setBackend);
     if (apt->reloadWhenSourcesEditorFinished())
         connect(apt, &QAptActions::sourcesEditorClosed, this, &ApplicationBackend::reload);
-    QAction* updateAction = w->actionCollection()->addAction(QStringLiteral("update"));
+    QAction* updateAction = w->addAction(QStringLiteral("update"));
     updateAction->setIcon(QIcon::fromTheme(QStringLiteral("system-software-update")));
     updateAction->setText(i18nc("@action Checks the Internet for updates", "Check for Updates"));
     updateAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_R));
@@ -577,7 +580,7 @@ void ApplicationBackend::setupTransaction(QApt::Transaction *trans)
         trans->setProxy(KProtocolManager::proxyFor(QStringLiteral("http")));
     }
 
-    trans->setLocale(QLatin1String(setlocale(LC_MESSAGES, 0)));
+    trans->setLocale(QLatin1String(setlocale(LC_MESSAGES, nullptr)));
 
     // Debconf
     QString uuid = QUuid::createUuid().toString();
