@@ -25,16 +25,17 @@
 #include <QStringList>
 #include <QTimer>
 
-Q_GLOBAL_STATIC(QVector<QString>, s_icons);
+Q_GLOBAL_STATIC(QVector<QString>, s_icons)
 
-DummyResource::DummyResource(QString  name, bool isTechnical, AbstractResourcesBackend* parent)
+DummyResource::DummyResource(QString name, bool isTechnical, AbstractResourcesBackend* parent)
     : AbstractResource(parent)
     , m_name(std::move(name))
     , m_state(State::Broken)
     , m_addons({ PackageState(QStringLiteral("a"), QStringLiteral("aaaaaa"), false), PackageState(QStringLiteral("b"), QStringLiteral("aaaaaa"), false), PackageState(QStringLiteral("c"), QStringLiteral("aaaaaa"), false)})
     , m_isTechnical(isTechnical)
 {
-    if(KRandom::random() % 2) {
+    const bool hasScreenshot = m_name == QStringLiteral("Dummy 1") || KRandom::random() % 2;
+    if(hasScreenshot) {
         m_screenshot = QUrl(QStringLiteral("http://screenshots.debian.net/screenshots/d/dolphin/9383_large.png"));
         m_screenshotThumbnail = QUrl(QStringLiteral("http://screenshots.debian.net/screenshots/d/dolphin/9383_small.png"));
     }
@@ -75,7 +76,7 @@ QStringList DummyResource::categories()
 
 QString DummyResource::comment()
 {
-    return QStringLiteral("comment ")+name()+QStringLiteral("...");
+    return QStringLiteral("A reasonably short comment ")+name();
 }
 
 int DummyResource::size()
