@@ -72,8 +72,7 @@ KNSBackend::KNSBackend(QObject* parent)
     , m_updater(new StandardBackendUpdater(this))
 {}
 
-KNSBackend::~KNSBackend()
-{}
+KNSBackend::~KNSBackend() = default;
 
 void KNSBackend::markInvalid()
 {
@@ -216,7 +215,7 @@ void KNSBackend::receivedContents(Attica::BaseJob* job)
     }
     QString filename = QFileInfo(m_name).fileName();
     foreach(const Attica::Content& c, contents) {
-        KNSResource* r = new KNSResource(c, filename, m_iconName, this);
+        KNSResource* r = new KNSResource(c, filename, this);
         m_resourcesByName.insert(c.id(), r);
         connect(r, &KNSResource::stateChanged, this, &KNSBackend::updatesCountChanged);
     }
@@ -279,7 +278,7 @@ void KNSBackend::installApplication(AbstractResource* app)
     transModel->removeTransaction(t);
 }
 
-void KNSBackend::installApplication(AbstractResource* app, const AddonList&)
+void KNSBackend::installApplication(AbstractResource* app, const AddonList& /*addons*/)
 {
     installApplication(app);
 }
