@@ -44,8 +44,8 @@ public:
     };
     Q_ENUMS(State)
 
-    DiscoverNotifier(QObject* parent = nullptr);
-    virtual ~DiscoverNotifier();
+    explicit DiscoverNotifier(QObject* parent = nullptr);
+    ~DiscoverNotifier() override;
 
     bool isSystemUpToDate() const;
 
